# This script is sourced by the main.R script.
# It loads data from file and cleans it up for analyses
# before saving to a new file 'cleaned_data.csv'

# Load the data from file ----
data_experimental <- read.csv2("data/raw_exp_data.csv")
data_clinical <- read.csv2("data/raw_clin_data.csv")

# Inspect the data ----
# It's always a good idea to inspect 
# your data before anything else

# First inspect the data structure
str(data_experimental)
str(data_clinical)
# Are all variables of the data type (integer, character, etc)
# you expected it to be?

# It's also a good idea to look for NA values / complete data
complete.cases(data_experimental)
complete.cases(data_clinical)
# How are you going to deal with NA values? ...R will NOT decide
# for you ... that's a good thing!

# Are all you data valid/meaningful? 
# E.g. an 'age' of 192 years might be an integer, but is
# it meaningful

# E.g. in this data set we expect the variable 'cpr' to be a 
# valid Danish CPR number of the format ddmmyy-xxxx 

# One way to check this is:
data_clinical %>% 
  pull(cpr) %>% 
  str_detect(pattern="^[0-9]{6}-[0-9]{4}$")

data_experimental %>% 
  pull(cpr) %>% 
  str_detect(pattern="^[0-9]{6}-[0-9]{4}$") 
# Are there any invalid CPR numbers in your data?

# Once you have a good overview of the data -- it's time to clean it ...
# This is probably an _iterative process_ ... i.e. you'll go back and 
# forth and adapt the code, notice something you missed the first time
# around, go back and revise the code, etc
# ...
# That's fine! ...as long as the end product is one, fully scripted
# reproducible process that loads RAW data and generates CLEANED data.

# Now we clean the data ----
# You may have noticed, that row numbers were cast as a variable X
# Let's get rid of it:
data_experimental <- data_experimental %>% select(-1)
data_clinical <- data_clinical %>% select(-1)

# What to do about wrong data type?
# ...simply recast character as factor
data_experimental <- data_experimental %>%
  mutate(tester = as.factor(tester)) %>%
  mutate(intervention = as.factor(intervention))

# What to do about incomplete cases? 
# ...lets just get rid of it for now
data_experimental <- data_experimental %>% na.omit() 
data_clinical <- data_clinical %>% na.omit() 

# In clinical data there is a few misshapen CPR numbers.
# We can could fix this manually, but for now, we just delete them
data_clinical <- data_clinical %>%
  filter(str_detect(cpr, pattern="^[0-9]{6}-[0-9]{4}$"))


# Manipulate the data ----
# Lets get the two data frames merged into one
# In this case, we use an 'inner_join', i.e. we
# only join complete observations from both data frames.
# What would happen if we did a full_join (or left or right)?
data_combo <- inner_join(
  data_experimental, 
  data_clinical, 
  by = 'cpr')

# You can just run the raw data load/clean code with every run, but
# especially if your data set is large, it may be helpful to store
# the cleaned data to file ... warning: this breaks the fully scripted
# chain of code from raw-data to presentations .. careful now!
# Save the clean data ----
write_rds(data_combo, "data/cleaned_data.rds")
# Saving in RDS keeps the data structure (e.g. factor vs string)

# ..or save as csv? (which does not save data types etc)
# write.csv2(data_combo, "data/cleaned_data.csv", row.names=FALSE)

# We can clear the data from memory now
rm(data_experimental)
rm(data_clinical)
rm(data_combo)

# At the end of this, we should have a 'tidy' data set:
# Read more at: https://cran.r-project.org/web/packages/tidyr/vignettes/tidy-data.html
