# **********************************************
# * EXAMPLE FOR CLASS ON REPRODUCIBLE RESEARCH *
# **********************************************


# This script:
#   * loads a data set by sourcing another script
#   * runs some analyses
#   * creates some output
#   * stores output to files

# The intention is to provide a real world example
# of workflow and file structuring in _reproducible
# research using the R ecosystem_



## SCRIPT STARTS HERE ----


# For future reference, store session info to file:
cat(capture.output(sessionInfo())
  , file="sessionInfo.txt", append=FALSE, sep="\n" 
)

## Load packages, etc ----
require(tidyverse)
require(ggplot2)
library(kableExtra)
source("custom_functions/SONs_text_functions.R")

# In a separate R script called "data/clean_up_the_raw_data.R", we loaded the
# raw data, cleaned it and saved it to a new file -- an RDS (R data structure).
# That way, the data cleaning is scripted, but we don't need to re-run it every
# time, we re-render out manuscript. 
my_data <- read_rds("data/cleaned_data.rds")

# ..alternatively, to use csv file IF you saved it as a csv file in clean_up_the_data.R
# my_data <- read.csv2("data/cleaned_data.csv", 
#                   header = TRUE,
#                   colClasses = c("character", "factor", "factor", "numeric", "integer", "integer"))

## Do some analyses ----
## Calculate a one-way anova
anova_result <- aov(measurement ~ intervention, data = my_data)
anova_summary <- summary(anova_result)

## Create some output ----
## Create a table of summary data
my_table_summary <- my_data %>%
  group_by(intervention) %>%
  summarise(
    count = n(),
    mean = mean(measurement, na.rm = TRUE),
    sd = sd(measurement, na.rm = TRUE)
  )
# Write it to file as HTML
cat(kable(my_table_summary), file = "tables/my_table_summary.html")

## Create a box plot
my_boxplot <- my_data %>%
  ggplot(aes(x = intervention, y = measurement, color=intervention)) +
  geom_boxplot() +
  geom_jitter()        
## Save the latest plot as a png file
ggsave("plots/my_boxplot_for_journal.png", device= "png", units = "cm", 
       width = 10, height = 10, dpi = 300)
ggsave("plots/my_boxplot_for_poster.png", device= "png", units = "cm", 
       width = 60, height = 60, dpi = 300)

## Create a simple variable: number of observations
n <- my_data %>% n_distinct()
